fn infer_format_from_path(source: &str) -> PromptFormatExpand description
Infers the prompt format from a file path or URL extension.
fn infer_format_from_path(source: &str) -> PromptFormatInfers the prompt format from a file path or URL extension.