pub struct SubcogConfig {Show 17 fields
pub repo_path: PathBuf,
pub data_dir: PathBuf,
pub features: FeatureFlags,
pub max_results: usize,
pub default_search_mode: SearchMode,
pub llm: LlmConfig,
pub search_intent: SearchIntentConfig,
pub observability: ObservabilitySettings,
pub prompt: PromptConfig,
pub storage: StorageConfig,
pub consolidation: ConsolidationConfig,
pub ttl: TtlConfig,
pub timeouts: OperationTimeoutConfig,
pub context_templates: ContextTemplatesConfig,
pub org: OrgConfig,
pub webhooks: WebhooksConfig,
pub config_sources: Vec<PathBuf>,
}Expand description
Main configuration for subcog.
Fields
repo_path: PathBufPath to the git repository.
data_dir: PathBufPath to the data directory.
features: FeatureFlagsFeature flags.
max_results: usizeMaximum number of search results.
default_search_mode: SearchModeDefault search mode.
llm: LlmConfigLLM provider configuration.
search_intent: SearchIntentConfigSearch intent configuration.
observability: ObservabilitySettingsObservability settings.
prompt: PromptConfigPrompt customization settings.
storage: StorageConfigStorage configuration.
consolidation: ConsolidationConfigConsolidation configuration.
ttl: TtlConfigTTL (Time-To-Live) configuration for memory expiration.
timeouts: OperationTimeoutConfigOperation timeout configuration (CHAOS-HIGH-005).
context_templates: ContextTemplatesConfigContext template configuration.
org: OrgConfigOrganization configuration for shared memory graphs.
webhooks: WebhooksConfigWebhook configuration.
config_sources: Vec<PathBuf>Config files that were loaded (for debugging).
Implementations
Sourceimpl SubcogConfig
impl SubcogConfig
Sourcepub fn load_from_file(path: &Path) -> Result<Self>
pub fn load_from_file(path: &Path) -> Result<Self>
Loads configuration from a file path.
Errors
Returns an error if the file cannot be read or parsed.
Sourcepub fn load_default() -> Self
pub fn load_default() -> Self
Loads configuration from the default location.
Config location: ~/.config/subcog/config.toml
Data location (platform-specific):
- macOS:
~/Library/Application Support/subcog/ - Linux:
~/.local/share/subcog/ - Windows:
C:\Users\<User>\AppData\Local\subcog\
Returns default configuration if no config file is found.
fn apply_env_overrides(&mut self)
Sourcefn apply_config_file(&mut self, file: ConfigFile)
fn apply_config_file(&mut self, file: ConfigFile)
Applies a ConfigFile to the current configuration.
ARCH-HIGH-002: Delegates to sub-config merge_from/from_config_file methods.
Sourcepub fn with_repo_path(self, path: impl Into<PathBuf>) -> Self
pub fn with_repo_path(self, path: impl Into<PathBuf>) -> Self
Sets the repository path.
Sourcepub fn with_data_dir(self, path: impl Into<PathBuf>) -> Self
pub fn with_data_dir(self, path: impl Into<PathBuf>) -> Self
Sets the data directory.