branch_exists

Function branch_exists 

pub fn branch_exists(branch: &str) -> bool
Performs a quick check if the current branch exists.

This is a lightweight operation that can be used in the recall path for lazy GC. It only checks the current branch, not all branches.

Arguments

  • branch - The branch name to check

Returns

true if the branch exists, false if it doesn’t or if the check fails.