pub struct NamespaceWeights {
weights: HashMap<Namespace, f32>,
}Expand description
Namespace weight multipliers for intent-based search.
Fields
weights: HashMap<Namespace, f32>Implementations
Sourceimpl NamespaceWeights
impl NamespaceWeights
Sourcepub fn for_intent(intent_type: SearchIntentType) -> Self
pub fn for_intent(intent_type: SearchIntentType) -> Self
Creates namespace weights for a specific intent type using hard-coded defaults.
Sourcepub fn for_intent_with_config(
intent_type: SearchIntentType,
config: &NamespaceWeightsConfig,
) -> Self
pub fn for_intent_with_config( intent_type: SearchIntentType, config: &NamespaceWeightsConfig, ) -> Self
Creates namespace weights for a specific intent type using config overrides.
Config weights take precedence over hard-coded defaults. If a namespace is not specified in config, the hard-coded default is used.
Sourcefn get_defaults(intent_type: SearchIntentType) -> Vec<(Namespace, f32)>
fn get_defaults(intent_type: SearchIntentType) -> Vec<(Namespace, f32)>
Gets the hard-coded default weights for an intent type.