pub struct CsvImportSource<R: BufRead> {
reader: Reader<R>,
column_map: ColumnMap,
}Expand description
CSV import source.
Reads CSV files with configurable column mapping. First row is expected to be headers unless configured otherwise.
Fields
reader: Reader<R>CSV reader.
column_map: ColumnMapColumn indices for each field.
Implementations
Sourceimpl<R: BufRead> CsvImportSource<R>
impl<R: BufRead> CsvImportSource<R>
Sourcepub fn new(reader: R) -> Result<Self>
pub fn new(reader: R) -> Result<Self>
Creates a new CSV import source.
Errors
Returns an error if headers cannot be read or ‘content’ column is missing.
Sourcefn parse_record(&self, record: &StringRecord) -> Result<ImportedMemory>
fn parse_record(&self, record: &StringRecord) -> Result<ImportedMemory>
Parses a record into an imported memory.