pub struct ImportService {
capture_service: Arc<CaptureService>,
}Expand description
Service for importing memories from external sources.
Fields
capture_service: Arc<CaptureService>Capture service for storing imported memories.
Implementations
Sourceimpl ImportService
impl ImportService
Sourcepub const fn new(capture_service: Arc<CaptureService>) -> Self
pub const fn new(capture_service: Arc<CaptureService>) -> Self
Creates a new import service.
Sourcepub fn import_from_file(
&self,
path: &Path,
options: ImportOptions,
progress: Option<ProgressCallback>,
) -> Result<ImportResult>
pub fn import_from_file( &self, path: &Path, options: ImportOptions, progress: Option<ProgressCallback>, ) -> Result<ImportResult>
Imports memories from a file.
Errors
Returns an error if the file cannot be read or format detection fails.
Sourcepub fn import_from_reader<R: BufRead + 'static>(
&self,
reader: R,
options: ImportOptions,
progress: Option<ProgressCallback>,
) -> Result<ImportResult>
pub fn import_from_reader<R: BufRead + 'static>( &self, reader: R, options: ImportOptions, progress: Option<ProgressCallback>, ) -> Result<ImportResult>
Sourcepub fn import_from_source(
&self,
source: &mut dyn ImportSource,
options: &ImportOptions,
progress: Option<ProgressCallback>,
) -> Result<ImportResult>
pub fn import_from_source( &self, source: &mut dyn ImportSource, options: &ImportOptions, progress: Option<ProgressCallback>, ) -> Result<ImportResult>
Imports memories from a source.
Errors
Returns an error if validation fails or storage errors occur.
Sourceconst fn memory_exists_with_tag(&self, _hash_tag: &str) -> Result<bool>
const fn memory_exists_with_tag(&self, _hash_tag: &str) -> Result<bool>
Checks if a memory with the given hash tag already exists.