pub struct ResilientLlmProvider<P: LlmProvider> {
inner: P,
config: LlmResilienceConfig,
breaker: Mutex<CircuitBreaker>,
budget: Mutex<BudgetTracker>,
}Expand description
LLM provider wrapper with circuit breaker and budget instrumentation.
Fields
inner: Pconfig: LlmResilienceConfigbreaker: Mutex<CircuitBreaker>budget: Mutex<BudgetTracker>Implementations
Sourceimpl<P: LlmProvider> ResilientLlmProvider<P>
impl<P: LlmProvider> ResilientLlmProvider<P>
Sourcepub fn new(inner: P, config: LlmResilienceConfig) -> Self
pub fn new(inner: P, config: LlmResilienceConfig) -> Self
Creates a new resilient LLM provider wrapper.
fn execute<T, F>(&self, operation: &'static str, call: F) -> Result<T>
fn record_success( &self, provider: &'static str, operation: &'static str, elapsed: Duration, )
fn handle_failure( &self, provider: &'static str, operation: &'static str, err: Error, elapsed: Duration, attempts: u32, max_attempts: u32, ) -> FailureAction
fn record_failure( &self, provider: &'static str, operation: &'static str, elapsed: Duration, is_timeout: bool, retryable: bool, )
fn record_breaker_success_state(&self) -> u8
fn record_request_metrics( &self, provider: &'static str, operation: &'static str, elapsed: Duration, is_error: bool, is_timeout: bool, )
fn record_budget_metrics( &self, provider: &'static str, operation: &'static str, ratio: f64, )
fn record_breaker_state(provider: &'static str, breaker_state: u8)
Sourcefn calculate_retry_delay(base_delay_ms: u64, attempt: u32) -> u64
fn calculate_retry_delay(base_delay_ms: u64, attempt: u32) -> u64
Calculates retry delay with exponential backoff and jitter (CHAOS-CRIT-001/002/003).
Formula: base_delay * 2^(attempt-1) + jitter
- Exponential growth prevents overwhelming a recovering service
- Jitter (0-50% of delay) prevents thundering herd problem
- Maximum delay capped at 10 seconds
Sourcefn calculate_jitter(delay_ms: u64) -> u64
fn calculate_jitter(delay_ms: u64) -> u64
Calculates jitter for retry backoff using system time as pseudo-random source.