pub struct PromptRegistry {
prompts: HashMap<String, PromptDefinition>,
}Expand description
Registry of pre-defined prompts.
Fields
prompts: HashMap<String, PromptDefinition>Available prompts.
Implementations
Sourceimpl PromptRegistry
impl PromptRegistry
Sourcefn all_prompts() -> Vec<PromptDefinition>
fn all_prompts() -> Vec<PromptDefinition>
Returns all prompt definitions.
fn session_start_prompt() -> PromptDefinition
fn session_start_alias_prompt() -> PromptDefinition
fn subcog_prompt() -> PromptDefinition
fn tutorial_prompt() -> PromptDefinition
fn generate_tutorial_definition() -> PromptDefinition
fn generate_tutorial_alias_prompt() -> PromptDefinition
fn capture_assistant_prompt() -> PromptDefinition
fn capture_prompt_alias() -> PromptDefinition
fn review_prompt() -> PromptDefinition
fn document_decision_prompt() -> PromptDefinition
fn generate_decision_alias_prompt() -> PromptDefinition
fn search_help_prompt() -> PromptDefinition
fn recall_prompt_alias() -> PromptDefinition
fn browse_prompt() -> PromptDefinition
fn list_prompt() -> PromptDefinition
fn intent_search_prompt() -> PromptDefinition
fn intent_search_alias_prompt() -> PromptDefinition
fn query_suggest_prompt() -> PromptDefinition
fn query_suggest_alias_prompt() -> PromptDefinition
fn context_capture_prompt() -> PromptDefinition
fn context_capture_alias_prompt() -> PromptDefinition
fn discover_prompt() -> PromptDefinition
fn discover_alias_prompt() -> PromptDefinition
Sourcepub fn list_prompts(&self) -> Vec<&PromptDefinition>
pub fn list_prompts(&self) -> Vec<&PromptDefinition>
Returns all prompt definitions (built-in only).
Sourcepub fn list_all_prompts(
&self,
prompt_service: &mut PromptService,
) -> Vec<PromptDefinition>
pub fn list_all_prompts( &self, prompt_service: &mut PromptService, ) -> Vec<PromptDefinition>
Returns all prompt definitions including user-defined prompts.
User prompts are fetched from the PromptService and combined with built-in prompts.
Built-in prompts take precedence if there are name conflicts.
Sourcepub fn get_prompt_with_user(
&self,
name: &str,
prompt_service: &mut PromptService,
) -> Option<PromptDefinition>
pub fn get_prompt_with_user( &self, name: &str, prompt_service: &mut PromptService, ) -> Option<PromptDefinition>
Gets a prompt definition by name, including user prompts.
User prompts are prefixed with “user/” (e.g., “user/code-review”).
Sourcepub fn get_prompt(&self, name: &str) -> Option<&PromptDefinition>
pub fn get_prompt(&self, name: &str) -> Option<&PromptDefinition>
Gets a prompt definition by name.
Sourcepub fn get_prompt_messages(
&self,
name: &str,
arguments: &Value,
) -> Option<Vec<PromptMessage>>
pub fn get_prompt_messages( &self, name: &str, arguments: &Value, ) -> Option<Vec<PromptMessage>>
Generates prompt messages for a given prompt and arguments.