pub fn entities_tool() -> ToolDefinitionExpand description
Defines the entities tool for entity CRUD operations.
Provides operations to create, read, update, and delete entities in the knowledge graph.
pub fn entities_tool() -> ToolDefinitionDefines the entities tool for entity CRUD operations.
Provides operations to create, read, update, and delete entities in the knowledge graph.