pub fn relationships_tool() -> ToolDefinitionExpand description
Defines the relationships tool for relationship CRUD operations.
Provides operations to create, read, and delete relationships between entities in the knowledge graph.
pub fn relationships_tool() -> ToolDefinitionDefines the relationships tool for relationship CRUD operations.
Provides operations to create, read, and delete relationships between entities in the knowledge graph.