pub fn execute_get_summary(arguments: Value) -> Result<ToolResult>Expand description
Executes the get summary tool. Retrieves a summary memory and its linked source memories.
pub fn execute_get_summary(arguments: Value) -> Result<ToolResult>Executes the get summary tool. Retrieves a summary memory and its linked source memories.