pub fn execute_restore(arguments: Value) -> Result<ToolResult>Expand description
Executes the restore tool - restores a tombstoned (soft-deleted) memory.
Sets the memory status back to Active and clears the tombstone timestamp.
pub fn execute_restore(arguments: Value) -> Result<ToolResult>Executes the restore tool - restores a tombstoned (soft-deleted) memory.
Sets the memory status back to Active and clears the tombstone timestamp.