pub fn execute_entity_merge(arguments: Value) -> Result<ToolResult>Expand description
Executes the entity merge tool (deduplication).
Errors
Returns an error if argument parsing or the operation fails.
pub fn execute_entity_merge(arguments: Value) -> Result<ToolResult>Executes the entity merge tool (deduplication).
Returns an error if argument parsing or the operation fails.