pub fn execute_relationships(arguments: Value) -> Result<ToolResult>Expand description
Executes the relationships tool (CRUD operations on relationships).
Errors
Returns an error if argument parsing or the operation fails.
pub fn execute_relationships(arguments: Value) -> Result<ToolResult>Executes the relationships tool (CRUD operations on relationships).
Returns an error if argument parsing or the operation fails.