pub enum EdgeType {
Contradicts,
Supersedes,
RelatedTo,
Refines,
ParentOf,
ChildOf,
SummarizedBy,
SourceOf,
}Expand description
Type of relationship edge between memories.
Variants
Contradicts
Memory A contradicts memory B.
Supersedes
Memory A supersedes memory B.
RelatedTo
Memory A is related to memory B.
Refines
Memory A refines memory B.
ParentOf
Memory A is a parent of memory B (hierarchy).
ChildOf
Memory A is a child of memory B (hierarchy).
SummarizedBy
Memory A is summarized by memory B (A is an original, B is the summary).
SourceOf
Memory A is a source of memory B (A is a summary, B is an original).
Implementations