pub struct BitemporalPoint {
pub valid_at: i64,
pub as_of: i64,
}Expand description
A bitemporal point representing both valid and transaction time.
This is useful for querying “what was known to be true at time T1, as of system time T2?”
Fields
valid_at: i64Point in valid time to query.
as_of: i64Point in transaction time to query.
Implementations
Sourceimpl BitemporalPoint
impl BitemporalPoint
Sourcepub const fn is_visible(
&self,
valid_time: &ValidTimeRange,
tx_time: &TransactionTime,
) -> bool
pub const fn is_visible( &self, valid_time: &ValidTimeRange, tx_time: &TransactionTime, ) -> bool
Checks if a record with given temporal metadata is visible at this point.