pub struct ObservabilityHandle {
tracer_provider: Option<SdkTracerProvider>,
logger_provider: Option<SdkLoggerProvider>,
metrics_handle: Option<MetricsHandle>,
tracing_runtime: Option<Runtime>,
}Expand description
Handle for observability runtime components.
Fields
tracer_provider: Option<SdkTracerProvider>logger_provider: Option<SdkLoggerProvider>metrics_handle: Option<MetricsHandle>tracing_runtime: Option<Runtime>Implementations
Sourceimpl ObservabilityHandle
impl ObservabilityHandle
Sourcepub fn shutdown(&mut self)
pub fn shutdown(&mut self)
Explicitly shuts down observability components.
This should be called before dropping the handle when running inside an async context to avoid panics from blocking operations.
Sourcefn flush_and_shutdown(
tracer: Option<SdkTracerProvider>,
logger: Option<SdkLoggerProvider>,
)
fn flush_and_shutdown( tracer: Option<SdkTracerProvider>, logger: Option<SdkLoggerProvider>, )
Flushes and shuts down tracer and logger providers.
Sourcefn shutdown_runtime(runtime: Option<Runtime>)
fn shutdown_runtime(runtime: Option<Runtime>)
Shuts down the tracing runtime with a timeout.
Sourcefn wait_for_batch_export(handle: &Handle)
fn wait_for_batch_export(handle: &Handle)
Waits briefly for the batch exporter to process pending exports.
Sourcefn shutdown_provider<T: ShutdownProvider>(provider: Option<T>)
fn shutdown_provider<T: ShutdownProvider>(provider: Option<T>)
Shuts down a tracer provider if present.