pub struct RenderContext {
values: HashMap<String, RenderValue>,
}Expand description
Context for rendering a template.
Fields
values: HashMap<String, RenderValue>Variable values keyed by name.
Implementations
Sourceimpl RenderContext
impl RenderContext
Sourcepub fn add_string(&mut self, name: impl Into<String>, value: impl Into<String>)
pub fn add_string(&mut self, name: impl Into<String>, value: impl Into<String>)
Adds a string value to the context.
Sourcepub fn add_list(
&mut self,
name: impl Into<String>,
items: Vec<HashMap<String, String>>,
)
pub fn add_list( &mut self, name: impl Into<String>, items: Vec<HashMap<String, String>>, )
Adds a list value to the context for iteration.
Sourcepub fn add_object(
&mut self,
name: impl Into<String>,
fields: HashMap<String, String>,
)
pub fn add_object( &mut self, name: impl Into<String>, fields: HashMap<String, String>, )
Adds an object value to the context.
Sourcepub fn add_value(&mut self, name: impl Into<String>, value: RenderValue)
pub fn add_value(&mut self, name: impl Into<String>, value: RenderValue)
Adds a render value to the context.
Sourcepub fn set(&mut self, name: impl Into<String>, value: RenderValue)
pub fn set(&mut self, name: impl Into<String>, value: RenderValue)
Sets a value in the context (alias for add_value).
Sourcepub fn get(&self, name: &str) -> Option<&RenderValue>
pub fn get(&self, name: &str) -> Option<&RenderValue>
Gets a value from the context.
Sourcepub fn get_string(&self, name: &str) -> Option<&str>
pub fn get_string(&self, name: &str) -> Option<&str>
Gets a string value from the context.
Sourcepub fn get_list(&self, name: &str) -> Option<&[HashMap<String, String>]>
pub fn get_list(&self, name: &str) -> Option<&[HashMap<String, String>]>
Gets a list value from the context.
Sourcepub fn to_string_map(&self) -> HashMap<String, String>
pub fn to_string_map(&self) -> HashMap<String, String>
Returns all values as a flat string map for variable substitution.