pub enum RenderValue {
String(String),
List(Vec<HashMap<String, String>>),
Object(HashMap<String, String>),
}Expand description
A value that can be rendered in a template.
Variants
String(String)
A simple string value.
List(Vec<HashMap<String, String>>)
A list of items for iteration.
Object(HashMap<String, String>)
A nested object (for statistics, etc.).
Implementations
Sourceimpl RenderValue
impl RenderValue
Sourcepub fn as_string(&self) -> Option<&str>
pub fn as_string(&self) -> Option<&str>
Returns the value as a string, or None if not a string.
Sourcepub fn as_list(&self) -> Option<&[HashMap<String, String>]>
pub fn as_list(&self) -> Option<&[HashMap<String, String>]>
Returns the value as a list, or None if not a list.
Sourcepub fn to_string_repr(&self) -> String
pub fn to_string_repr(&self) -> String
Converts the value to a string representation.