pub struct EncryptionConfig {
key: [u8; 32],
}Expand description
Encryption configuration.
Fields
key: [u8; 32]Raw 32-byte encryption key.
Implementations
Sourceimpl EncryptionConfig
impl EncryptionConfig
Sourcepub fn from_base64(key_b64: &str) -> Result<Self>
pub fn from_base64(key_b64: &str) -> Result<Self>
Creates configuration from a base64-encoded key.
Errors
Returns an error if the key is invalid or wrong size.
Sourcepub fn from_env() -> Result<Self>
pub fn from_env() -> Result<Self>
Loads configuration from environment variable.
Errors
Returns an error if SUBCOG_ENCRYPTION_KEY is not set or invalid.
Sourcepub fn try_from_env() -> Option<Self>
pub fn try_from_env() -> Option<Self>
Tries to load configuration from environment, returns None if not configured.