init_global

Function init_global 

pub fn init_global(config: AuditConfig) -> Result<()>
Initializes the global audit logger.

Errors

Returns an error if the log directory cannot be created or if the global audit logger has already been initialized.