pub struct ContentRedactor {
secret_detector: SecretDetector,
pii_detector: PiiDetector,
config: RedactionConfig,
}Expand description
Redacts sensitive content from text.
Fields
secret_detector: SecretDetectorpii_detector: PiiDetectorconfig: RedactionConfigImplementations
Sourceimpl ContentRedactor
impl ContentRedactor
Sourcepub const fn with_config(config: RedactionConfig) -> Self
pub const fn with_config(config: RedactionConfig) -> Self
Creates a new content redactor with custom config.
Sourcepub const fn config(&self) -> &RedactionConfig
pub const fn config(&self) -> &RedactionConfig
Returns the configuration.
Sourcepub fn redact(&self, content: &str) -> String
pub fn redact(&self, content: &str) -> String
Redacts sensitive content, returning the redacted text.
Sourcepub fn redact_with_flag(&self, content: &str) -> (String, bool)
pub fn redact_with_flag(&self, content: &str) -> (String, bool)
Returns the redacted content and a flag indicating if anything was redacted.
Sourcepub fn needs_redaction(&self, content: &str) -> bool
pub fn needs_redaction(&self, content: &str) -> bool
Checks if content needs redaction.
Sourcepub fn detected_types(&self, content: &str) -> Vec<String>
pub fn detected_types(&self, content: &str) -> Vec<String>
Returns the types of sensitive content found.
Sourcefn log_pii_detection_if_any(&self, pii_matches: &[PiiMatch])
fn log_pii_detection_if_any(&self, pii_matches: &[PiiMatch])
Logs PII detection events for audit compliance (GDPR/SOC2).
Only logs when matches are found to avoid noise.
Sourcefn get_replacement(&self, type_name: &str, length: usize) -> String
fn get_replacement(&self, type_name: &str, length: usize) -> String
Gets the replacement string based on mode.