pub trait ThreadSafeEmbedder:
Embedder
+ Send
+ Sync { }Expand description
Thread-safe embedder backend.
Trait alias for embedders that can be shared across threads.
All embedders used with SemanticSimilarityChecker must implement this.
Note: This trait is used as a bound on generic parameters. The dead_code
lint doesn’t recognize trait bound usage, hence the allow attribute.