pub enum ConsentPurpose {
DataStorage,
DataProcessing,
EmbeddingGeneration,
LlmProcessing,
RemoteSync,
Analytics,
}Expand description
Purpose for which consent is granted.
GDPR requires consent to be specific to a purpose. This enum defines the granular purposes for which consent can be granted or revoked.
Variants
DataStorage
Storage of memory data.
DataProcessing
Processing for search and recall.
EmbeddingGeneration
Generation of embeddings for semantic search.
LlmProcessing
Use of LLM for enrichment and analysis.
RemoteSync
Sync to remote storage.
Analytics
Analytics and metrics collection.
Implementations