pub struct CaptureOrchestrator {
capture: Option<CaptureService>,
dedup: Option<Arc<dyn Deduplicator>>,
}Expand description
Orchestrates capture operations with deduplication support.
Fields
capture: Option<CaptureService>Capture service instance.
dedup: Option<Arc<dyn Deduplicator>>Deduplication service instance (trait object for flexibility).
Implementations
Sourceimpl CaptureOrchestrator
impl CaptureOrchestrator
Sourcepub fn with_capture(self, capture: CaptureService) -> Self
pub fn with_capture(self, capture: CaptureService) -> Self
Sets the capture service.
Sourcepub fn with_deduplication(self, dedup: Arc<dyn Deduplicator>) -> Self
pub fn with_deduplication(self, dedup: Arc<dyn Deduplicator>) -> Self
Sets the deduplication service.
Sourcepub fn has_deduplication(&self) -> bool
pub fn has_deduplication(&self) -> bool
Returns whether deduplication is configured.
This method is primarily used in tests to verify builder configuration.
Sourcepub fn capture_candidates(
&self,
candidates: Vec<CaptureCandidate>,
) -> (Vec<CapturedMemory>, Vec<SkippedDuplicate>)
pub fn capture_candidates( &self, candidates: Vec<CaptureCandidate>, ) -> (Vec<CapturedMemory>, Vec<SkippedDuplicate>)
Performs the actual capture of candidates.
If a deduplication service is configured, checks each candidate for duplicates before capture. Returns both captured memories and skipped duplicates.
Note: If no capture service is configured, this method returns empty results
and logs a debug message. Configure a capture service using [with_capture].
Sourcefn check_for_duplicate(
&self,
candidate: &CaptureCandidate,
) -> Option<SkippedDuplicate>
fn check_for_duplicate( &self, candidate: &CaptureCandidate, ) -> Option<SkippedDuplicate>
Checks if a candidate is a duplicate and returns skip info if so.
Returns Some(SkippedDuplicate) if the candidate should be skipped,
None if it should be captured.
Sourcefn record_capture_for_dedup(&self, content: &str, memory_id: &MemoryId)
fn record_capture_for_dedup(&self, content: &str, memory_id: &MemoryId)
Records a successful capture in the deduplication service.