pub fn execute_recall(arguments: Value) -> Result<ToolResult>Expand description
Executes the recall tool.
When query is omitted or empty, behaves like subcog_list and returns
all memories matching the filter criteria (with pagination support).
pub fn execute_recall(arguments: Value) -> Result<ToolResult>Executes the recall tool.
When query is omitted or empty, behaves like subcog_list and returns
all memories matching the filter criteria (with pagination support).