pub fn flush(handle: &MetricsHandle)Expand description
Flushes metrics to the push gateway if configured.
When called from within a tokio runtime, this spawns a separate thread
to avoid runtime nesting issues with reqwest::blocking::Client.
pub fn flush(handle: &MetricsHandle)Flushes metrics to the push gateway if configured.
When called from within a tokio runtime, this spawns a separate thread
to avoid runtime nesting issues with reqwest::blocking::Client.