pub fn init_global(config: AuditConfig) -> Result<()>Expand description
Initializes the global audit logger.
Errors
Returns an error if the log directory cannot be created or if the global audit logger has already been initialized.
pub fn init_global(config: AuditConfig) -> Result<()>Initializes the global audit logger.
Returns an error if the log directory cannot be created or if the global audit logger has already been initialized.